==> site_audit_checklist-1.0.0.zip: site_audit_checklist/src/Controller/SiteAuditChecklistController.php <==
<?php

namespace Drupal\site_audit_checklist\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Database\Connection;
use Symfony\Component\DependencyInjection\ContainerInterface;

class SiteAuditChecklistController extends ControllerBase {

  protected $configFactory;
  protected $database;

  public function __construct(ConfigFactoryInterface $config_factory, Connection $database) {
    $this->configFactory = $config_factory;
    $this->database = $database;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('database')
    );
  }

  public function dashboard() {
    // Load task statuses from the database.
    $query = $this->database->select('site_audit_checklist_status', 's')
      ->fields('s');
    $tasks = $query->execute()->fetchAllAssoc('task_id');
  
    // Load task statuses from the database.
    $query = $this->database->select('site_audit_checklist_status', 's')
      ->fields('s');
    $tasks = $query->execute()->fetchAllAssoc('task_id');
  
    // The database query returns an array of objects, so access them as objects.
    $completed_tasks = array_filter($tasks, function ($task) {
        // Access the status property using object syntax.
        return (bool) $task->status;
    });
    
    $progress_percentage = count($tasks) > 0 ? (count($completed_tasks) / count($tasks)) * 100 : 0;
  
    return [
      '#theme' => 'site-audit-checklist-dashboard',
      '#tasks' => $tasks,
      '#progress' => round($progress_percentage),
      '#attached' => [
        'library' => [
          'site_audit_checklist/styles',
        ],
      ],
    ];
  }
}

==> site_audit_checklist-1.2.0.zip: site_audit_checklist/src/Controller/SiteAuditChecklistController.php <==
<?php

namespace Drupal\site_audit_checklist\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Database\Connection;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\StreamedResponse;

class SiteAuditChecklistController extends ControllerBase {

  protected $configFactory;
  protected $database;

  public function __construct(ConfigFactoryInterface $config_factory, Connection $database) {
    $this->configFactory = $config_factory;
    $this->database = $database;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('database')
    );
  }

  public function dashboard() {
    // Load task statuses from the database.
    $query = $this->database->select('site_audit_checklist_status', 's')
      ->fields('s');
    $tasks = $query->execute()->fetchAllAssoc('task_id');
  
    // Load task statuses from the database.
    $query = $this->database->select('site_audit_checklist_status', 's')
      ->fields('s');
    $tasks = $query->execute()->fetchAllAssoc('task_id');
  
    // The database query returns an array of objects, so access them as objects.
    $completed_tasks = array_filter($tasks, function ($task) {
        // Access the status property using object syntax.
        return (bool) $task->status;
    });
    
    $progress_percentage = count($tasks) > 0 ? (count($completed_tasks) / count($tasks)) * 100 : 0;
  
    return [
      '#theme' => 'site-audit-checklist-dashboard',
      '#tasks' => $tasks,
      '#progress' => round($progress_percentage),
      '#attached' => [
        'library' => [
          'site_audit_checklist/styles',
        ],
      ],
    ];
  }

  /**
   * Streams the checklist status records as a CSV download.
   */
  public function exportCsv() {
    $response = new StreamedResponse();
    $response->setCallback(function () {
      $handle = fopen('php://output', 'w');

      // Header row.
      fputcsv($handle, [
        'task_id',
        'status',
        'notes',
        'completed_by',
        'completed_timestamp',
      ]);

      $result = $this->database->select('site_audit_checklist_status', 's')
        ->fields('s')
        ->execute();

      foreach ($result as $row) {
        fputcsv($handle, [
          $row->task_id,
          (int) $row->status,
          $row->notes,
          $row->completed_by,
          $row->completed_timestamp,
        ]);
      }

      fclose($handle);
    });

    $filename = 'site-audit-checklist-' . date('Ymd-His') . '.csv';
    $response->headers->set('Content-Type', 'text/csv');
    $response->headers->set('Content-Disposition', 'attachment; filename="' . $filename . '"');

    return $response;
  }
}
